@@ -1,26 +1,34 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals
+
 from markdown2 import markdown, markdown_path
 from weasyprint import HTML, CSS
 
 from .exceptions import ValidationError
 
 
-__title__ = 'md2pdf'
-__version__ = '0.3'
-__author__ = 'Julien Maupetit'
-__license__ = 'MIT'
-__copyright__ = 'Copyright 2013 Julien Maupetit'
-
-
 def md2pdf(pdf_file_path, md_content=None, md_file_path=None,
            css_file_path=None, base_url=None):
     """
-    Convert markdown file to pdf with styles
+    Converts input markdown to styled HTML and renders it to a PDF file.
+
+    Args:
+        pdf_file_path: output PDF file path.
+        md_content: input markdown raw string content.
+        md_file_path: input markdown file path.
+        css_file_path: input styles path (CSS).
+        base_url: absolute base path for markdown linked content (as images).
+
+    Returns:
+        None
+
+    Raises:
+        ValidationError: if md_content and md_file_path are empty.
     """
 
     # Convert markdown to html
-    raw_html = ""
-    extras = ["cuddled-lists"]
+    raw_html = ''
+    extras = ['cuddled-lists', 'tables']
     if md_file_path:
         raw_html = markdown_path(md_file_path, extras=extras)
     elif md_content:
